==> mollie-2.1.x-dev.tar.gz: mollie/modules/mollie_commerce/src/PluginForm/OffsiteRedirect/MolliePaymentOffsiteForm.php <==
<?php

namespace Drupal\mollie_commerce\PluginForm\OffsiteRedirect;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mollie\Entity\Payment;
use Drupal\mollie\Mollie;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class MolliePaymentOffsiteForm.
 *
 * @package Drupal\mollie_commerce\PluginForm\OffsiteRedirect
 */
class MolliePaymentOffsiteForm extends PaymentOffsiteForm implements ContainerInjectionInterface {

  /**
   * Mollie service.
   *
   * @var \Drupal\mollie\Mollie
   */
  protected $mollie;

  /**
   * MolliePaymentOffsiteForm constructor.
   *
   * @param \Drupal\mollie\Mollie $mollie
   *   Mollie service.
   */
  public function __construct(Mollie $mollie) {
    $this->mollie = $mollie;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('mollie.mollie')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;

    // Initialize the Mollie payment.
    $transaction = Payment::create([
      'amount' => $payment->getAmount()->getNumber(),
      'currency' => $payment->getAmount()->getCurrencyCode(),
      // TODO: Better description.
      'description' => "Order #{$payment->getOrder()->id()}",
      'context' => 'mollie_commerce',
      'context_id' => $payment->getOrderId(),
    ]);

    try {
      // Create the Mollie payment.
      $transaction->save();

      // Store the Commerce payment.
      $payment->setRemoteId($transaction->id());
      $payment->save();

      // Redirect to Mollie.
      return $this->buildRedirectForm($form, $form_state, $transaction->getCheckoutUrl(), [], 'get');
    }
    catch (EntityStorageException $e) {
      watchdog_exception('mollie_commerce', $e);
    }
    return [];
  }

}

==> mollie-2.2.x-dev.tar.gz: mollie/modules/mollie_commerce/src/PluginForm/OffsiteRedirect/MolliePaymentOffsiteForm.php <==
<?php

namespace Drupal\mollie_commerce\PluginForm\OffsiteRedirect;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mollie\Entity\Payment;
use Drupal\mollie\Mollie;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class MolliePaymentOffsiteForm.
 *
 * @package Drupal\mollie_commerce\PluginForm\OffsiteRedirect
 */
class MolliePaymentOffsiteForm extends PaymentOffsiteForm implements ContainerInjectionInterface {

  /**
   * Mollie service.
   *
   * @var \Drupal\mollie\Mollie
   */
  protected $mollie;

  /**
   * MolliePaymentOffsiteForm constructor.
   *
   * @param \Drupal\mollie\Mollie $mollie
   *   Mollie service.
   */
  public function __construct(Mollie $mollie) {
    $this->mollie = $mollie;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('mollie.mollie')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;

    // Initialize the Mollie payment.
    $transaction = Payment::create([
      'amount' => $payment->getAmount()->getNumber(),
      'currency' => $payment->getAmount()->getCurrencyCode(),
      'description' => $this->t('@store order @order_id', [
        '@store' => $payment->getOrder()->getStore()->label(),
        '@order_id' => $payment->getOrderId(),
      ]),
      'context' => 'mollie_commerce',
      'context_id' => $payment->getOrderId(),
    ]);

    try {
      // Create the Mollie payment.
      $transaction->save();

      // Store the Commerce payment.
      $payment->setRemoteId($transaction->id());
      $payment->save();

      // Redirect to Mollie.
      return $this->buildRedirectForm($form, $form_state, $transaction->getCheckoutUrl(), [], 'get');
    }
    catch (EntityStorageException $e) {
      watchdog_exception('mollie_commerce', $e);
    }
    return [];
  }

}
